/* -*- Mode: IDL; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Jean-Francois Ducarroz <ducarroz@netscape.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsIOutputStream.idl"
#include "nsIFile.idl"


%{C++
#define NS_APPLEFILEDECODER_CLASSNAME    "Apple Single/Double File decoder"

#define NS_APPLEFILEDECODER_CID                      \
{ /* 3a2bb281-64b8-11d5-9daa-bb433143c53c */         \
    0x3a2bb281,                                      \
    0x64b8,                                          \
    0x11d5,                                          \
    {0x9d, 0xaa, 0xbb, 0x43, 0x31, 0x43, 0xc5, 0x3c} \
}

#define NS_IAPPLEFILEDECODER_CONTRACTID     "@mozilla.org/applefiledecoder;1"
%}


[scriptable, uuid(3a2bb280-64b8-11d5-9daa-bb433143c53c)]
interface nsIAppleFileDecoder : nsIOutputStream {

    /**
     * Initialize the Apple File Decoder Output stream.
     *
     * @param outputStream     The output stream which the AppleFile Decoder will write to the data fork.
     * @param outputFile       The output file which the AppleFile Decoder will write to the resource fork.
     */
    void Initialize(in nsIOutputStream outputStream, in nsIFile outputFile);
};
